| autoplot.pte_qtt | R Documentation |
Plot a pte_qtt object.
For type = "overall": QTT curve with quantile on the x-axis.
For type = "dynamic": event-study plot with event time on the x-axis.
Each selected quantile is a separate colored line. CIs are shown by default
when a single quantile is plotted, and suppressed by default when multiple
quantiles are plotted.
## S3 method for class 'pte_qtt'
autoplot(
object,
type = "overall",
cband = TRUE,
plot_probs = 0.5,
plot_ci = NULL,
...
)
object |
a |
type |
which aggregation to plot: |
cband |
logical; if |
plot_probs |
numeric vector of quantile levels to show in the dynamic
plot. Defaults to |
plot_ci |
logical or |
... |
unused |
a ggplot object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.