View source: R/attgt_functions.R
| did_rcs_attgt | R Documentation |
Takes a local repeated cross sections data set and computes an estimate of a group-time average treatment effect and corresponding influence function using a repeated cross sections DID approach.
did_rcs_attgt(gt_data, xformula = ~1, est_method = "dr", ...)
gt_data |
data that is "local" to a particular group-time average treatment effect |
xformula |
one-sided formula for covariates used in the propensity score and outcome regression models |
est_method |
Which type of estimation method to use. Default is "dr" for doubly robust. The other option is "reg" for regression adjustment. |
... |
extra function arguments; not used here |
attgt_if
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.