| pte_qtt | R Documentation |
Holds the full quantile treatment effect (QTT) curve at the
overall, group-specific, and dynamic (event-study) aggregation levels.
Each aggregation contains estimates at all quantile levels in probs
together with bootstrap standard errors and pointwise confidence intervals.
pte_qtt(overall, dynamic, group, F0_overall = NULL, F1_overall = NULL, ptep)
overall |
data.frame with columns |
dynamic |
data.frame with columns |
group |
data.frame with columns |
F0_overall |
mixture CDF of untreated potential outcomes |
F1_overall |
mixture CDF of treated potential outcomes |
ptep |
|
a pte_qtt object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.